@@ -189,6 +189,12 @@ data = {
                         "default": None,
                         "help": "keep major version at zero, even for breaking changes",
                     },
+                    {
+                        "name": ["--prerelease-offset"],
+                        "type": int,
+                        "default": None,
+                        "help": "start pre-releases with this offset",
+                    },
                     {
                         "name": "manual_version",
                         "type": str,
